@@ -58,18 +58,23 @@ class BaseCache():
         if len(self.data) <= self.last_save_len:
             self.lock.release()
             return
-        logger.info(f'Saving cache {self.fp}')
+        logger.debug(f'Saving cache {self.fp}')
         self.create_dirs()
         with open(self.fp, 'wb') as f:
             pickle.dump(self.data, f)
         self.last_save_len = len(self.data)
         self.lock.release()
 
+    def delete(self):
+        if os.path.exists(self.fp):
+            os.remove(self.fp)
+        self.unload()
+
     def load(self):
         if self.loaded:
             return
 
-        logger.info(f'Loading cache {self.fp}')
+        logger.debug(f'Loading cache {self.fp}')
         if not os.path.exists(self.fp):
             self.create_dirs()
             self.save()
@@ -92,6 +97,7 @@ class BaseCache():
     def unload(self):
         self.lock.acquire()
         self.data = {}
+        self.last_save_len = -1
         self.lock.release()
         self.loaded = False
 
