@@ -3,6 +3,8 @@ import sys
 import logging
 from logging.handlers import RotatingFileHandler
 
+import logging_loki
+
 from via.constants import LOG_LOCATION
 
 
@@ -41,6 +43,16 @@ os.makedirs(
     exist_ok=True
 )
 
+if os.getenv('LOKI_ENDPOINT') == 'True':
+    handler = logging_loki.LokiHandler(
+        url=os.getenv('LOKI_ENDPOINT'),
+        tags={"application": "via"},
+        auth=(os.getenv('LOKI_USERNAME'), os.getenv('LOKI_PASSWORD')),
+        version="1",
+    )
+    logger.addHandler(handler)
+
+
 handler = RotatingFileHandler(
     LOG_LOCATION,
     maxBytes=1000000,
