@@ -1,6 +1,9 @@
+import os
+
 from unittest import TestCase
 from mock import patch
 
+from via.settings import VERSION
 from via.base_cache import BaseCache
 
 
@@ -27,29 +30,41 @@ class BaseCacheTest(TestCase):
             1
         )
 
-    def test_save(self):
-        cache = BaseCache(cache_type='test_get')
-        cache.set('one', 1)
+    def test_delete(self):
+        cache = BaseCache(cache_type='test_delete')
+        cache.set('one', 1, skip_save=True)
+        cache.set('two', 2, skip_save=True)
         cache.save()
 
-        cache = BaseCache(cache_type='test_get')
+        self.assertTrue(os.path.exists(cache.fp))
+
+        cache.delete()
+
+        self.assertFalse(os.path.exists(cache.fp))
+
+    def test_save(self):
+        cache = BaseCache(cache_type='test_save')
+        cache.delete()
+        cache.set('one', 1, skip_save=True)
+        cache.set('two', 2, skip_save=True)
+        cache.save()
+
+        cache = BaseCache(cache_type='test_save')
         self.assertEqual(
             cache.get('one'),
             1
         )
 
     def test_load_content(self):
-        cache = BaseCache(cache_type='test_get')
+        cache = BaseCache(cache_type='test_load_content')
         cache.set('one', 1)
         cache.save()
 
-        cache = BaseCache(cache_type='test_get')
+        cache = BaseCache(cache_type='test_load_content')
         cache.load()
         self.assertEqual(
-            cache.data,
-            {
-                'one': 1
-            }
+            cache.data['one'],
+            1
         )
 
     def test_load_empty(self):
@@ -58,6 +73,11 @@ class BaseCacheTest(TestCase):
         self.assertTrue(cache.loaded)
         self.assertEqual(cache.data, {})
 
+    def test_create_dirs(self):
+        cache = BaseCache(cache_type='testcreatedirs')
+        cache.create_dirs()
+        self.assertTrue(os.path.exists(os.path.dirname(cache.fp)))
+
     @patch('via.settings.VERSION', '0.0.1')
     def test_dir(self):
         from via import settings
